@@ -658,7 +658,7 @@ def execute_strategy_multi_asset(
                     if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
                         float_number_to_be_bought = round(
                             (
-                                (df_trading_journal['Portfolio value'] * row['percentage_to_be_bought']) - dict_constraints['float_minimum_cash']
+                                (df_trading_journal.iloc[-1]['Portfolio value'] * row['percentage_to_be_bought']) - dict_constraints['float_minimum_cash']
                             ) / float_price,
                             dict_general_settings['int_rounding_decimal_places_for_security_quantities']
                         )
@@ -693,7 +693,7 @@ def execute_strategy_multi_asset(
                     if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
                         float_number_to_be_bought = round(
                             (
-                                (df_trading_journal['Portfolio value'] * row['percentage_to_be_bought'])
+                                (df_trading_journal.iloc[-1]['Portfolio value'] * row['percentage_to_be_bought'])
                             ) / float_price,
                             dict_general_settings['int_rounding_decimal_places_for_security_quantities']
                         )
